.. _api_reference:

*************
API Reference
*************

.. meta::
   :description: API Reference for sponsorblock.py
   :keywords: sponsorblock.py, documentation, sponsorblock, python, wrapper, api, reference
   :author: Wasi Master

.. toctree::
   :maxdepth: 4


Submodules
==========

sponsorblock.client module
--------------------------
The client module provides a Client for the SponsorBlock API.

.. automodule:: sponsorblock.client
   :members:
   :undoc-members:
   :show-inheritance:

sponsorblock.models module
--------------------------

.. automodule:: sponsorblock.models
   :members:
   :undoc-members:
   :show-inheritance:

sponsorblock.errors module
--------------------------

.. automodule:: sponsorblock.errors
   :members:
   :undoc-members:
   :show-inheritance:


sponsorblock.utils module
-------------------------

.. automodule:: sponsorblock.utils
   :members:
   :undoc-members:
   :show-inheritance:
